{% extends "base.html" %}
{% block title %}{{ nickname }} - özgürsözlük{% endblock %}
{% block meta %}<meta name="title" content="{{ nickname }} - özgürsözlük">{% endblock %}
{% block main %}
    <div class="topic-nav">
        <div class="topic-nav-item">
            <p>
                Author: <a href="{{ url_for("author", nickname=nickname) }}">{{ nickname }}</a>
            </p>
        </div>
    </div>
    <div class="author-badges-container">
        {% for badge in badges %}
            <div class="author-badge-container">
                <div class="badge-box">
                    <img class="author-badge-icon" src="{{ badge.icon_url }}" />
                </div>
                <div class="badge-box">
                    <p class="author-badge-name">{{ badge.name }}</p>
                    <small class="author-badge-description">{{ badge.description }}</small>
                </div>
            </div>
        {% endfor %}
    </div>
{% endblock %}
